#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Views for CourseInfo
"""


from zope.component import adapter
from zope.interface import implementer
from zope.publisher.browser import BrowserView
from zope.publisher.interfaces.browser import IBrowserRequest
from zope.traversing.browser.absoluteurl import absoluteURL
from zope.traversing.browser.interfaces import IAbsoluteURL

from schooltool.courseinfo import interfaces
from schooltool.schoolyear.interfaces import ISchoolYear


@adapter(interfaces.ICourseInfoSchoolYear, IBrowserRequest)
@implementer(IAbsoluteURL)
class CourseInfoSchoolYearAbsoluteURLAdapter(BrowserView):
    def __str__(self):
        year = ISchoolYear(self.context)
        return absoluteURL(year, self.request) + '/courseinfo'

    __call__ = __str__


class CurrentCourseInfoRedirectView(BrowserView):
    def __call__(self):
        course = self.context
        courseinfo = interfaces.ICurrentCourseInfo(course)

        url = absoluteURL(courseinfo, self.request)
        self.request.response.redirect(url)


class PublishedCourseInfoRedirectView(BrowserView):
    def __call__(self):
        courseinfo = interfaces.IPublishedCourseInfo(self.context)

        if courseinfo:
            url = absoluteURL(courseinfo, self.request)
            self.request.response.redirect(url)
            return

        # If this point is reached, the adapter failed, therefore the
        # PublishedCourseInfo doesn't exist in the POS and this view's template
        # needs to be rendered (a "not found" view)

        return super(PublishedCourseInfoRedirectView, self)()


class CourseInfoContainerView(BrowserView):
    def __init__(self, context, request):
        super(CourseInfoContainerView, self).__init__(context, request)

    def courseinfos(self):
        results = []
        for key in self.context:
            result = {'title': self.context[key].title,
                      'url': key}
            results.append(result)
        return sorted(results, key=lambda r: r['title'])

class CourseInfoRevisionContainerView(BrowserView):
    def __init__(self, context, request):
        super(CourseInfoRevisionContainerView, self).__init__(context, request)

    def courseinfos(self):
        results = []
        for key in self.context:
            result = {'title': self.context[key].title,
                      'url': key}
            results.append(result)
        return results

class CourseInfoRevisionRedirectView(BrowserView):
    def __call__(self):
        currentcourseinfo = self.context
        courseinfo = interfaces.ICourseInfoRevision(currentcourseinfo)

        url = absoluteURL(courseinfo, self.request)+"/edit.html"
        self.request.response.redirect(url)

