#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Implementation of CSV import for PublishedCourseInfo objects.
"""

from schooltool.app.browser.csvimport import BaseCSVImporter, BaseCSVImportView
from schooltool.courseinfo.courseinfo import PublishedCourseInfo

from zope.container.interfaces import INameChooser

from schooltool.common import SchoolToolMessage as _


class PublishedCourseInfoCSVImporter(BaseCSVImporter):

       def createAndAdd(self, data, dry_run=True):
              if len(data) < 3 or not data[2].strip():
                     self.errors.fields.append(_('Insufficient data provided.'))
                     return
              if not data[2]:
                     self.errors.fields.append(_('Course title may not be empty.'))
                     return

              # Round out the data with blank values if it's too short
              data = data + [None]*(21-len(data))

              course_id = data[0]
              government_id = data[1]
              title = data[2]
              description = data[3]
              start_grade = data[4]
              end_grade = data[5]
              duration = data[6]
              credits = data[7]
              elective = data[8]
              division = data[9]
              cluster = data[10]
              pathway = data[11]
              prerequisite = data[12] ## List?
              credit_codes = data[13]
              supervisor = data[14]
              weight = data[15]
              lab_fee = data[16]
              requirements = data[17]
              course_description = data[18]
              outcomes = data[19]
              notes = data[20]
              
              # Cast an object to an int, handling None properly.
              _int = lambda obj: int(obj) if obj is not None else None

              # Cast an object to a float, handling None properly. 
              _float = lambda obj: float(obj) if obj is not None else None

              # Parse a pipe-separated list, handling None properly.
              _list = lambda obj: [x.strip() for x in obj.split('|')] if obj is not None else []

              # Parse a boolean value, handling None properly.
              _bool = lambda obj: (obj.lower() in ('yes','true','1')) if obj else None

              courseinfo = PublishedCourseInfo(title)
              courseinfo.course_id = course_id
              courseinfo.government_id = government_id
              courseinfo.title = title
              courseinfo.description = description
              courseinfo.start_grade = _int(start_grade)
              courseinfo.end_grade = _int(end_grade)
              courseinfo.duration = _int(duration)
              courseinfo.credits = _float(credits)
              courseinfo.elective = _bool(elective)
              courseinfo.division = division
              courseinfo.cluster = cluster
              courseinfo.pathway = pathway
              courseinfo.prerequisite = _list(prerequisite) ## List?
              courseinfo.credit_codes = _list(credit_codes)
              courseinfo.supervisor = supervisor
              courseinfo.weight = _float(weight)
              courseinfo.lab_fee = _float(lab_fee)
              courseinfo.requirements = requirements
              courseinfo.course_description = _list(course_description)
              courseinfo.outcomes = outcomes
              courseinfo.notes = notes

              if not dry_run:
                     chooser = INameChooser(self.container)
                     name = chooser.chooseName('', courseinfo)
                     self.container[name] = courseinfo


class PublishedCourseInfoCSVImportView(BaseCSVImportView):
    """View for PublishedCourseInfo CSV importer."""

    importer_class = PublishedCourseInfoCSVImporter
