#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Unit tests for course and section implementations.
"""
import unittest
import doctest

from zope.app.testing import setup
from zope.component import provideAdapter, provideUtility
from zope.intid.interfaces import IIntIds

from schooltool.course.course import (getSchoolYearForCourse,
                                      getCourseContainer,
                                      getSchoolYearForCourseContainer)
from schooltool.courseinfo import adapters
from schooltool.relationship.tests import setUpRelationships
from schooltool.schoolyear.schoolyear import getSchoolYearContainer


def setUp(test=None):
    setup.placefulSetUp()
    setUpRelationships()
    setup.setUpAnnotations()

    provideAdapter(getSchoolYearContainer)
    provideAdapter(getSchoolYearForCourse)
    provideAdapter(getCourseContainer)
    provideAdapter(getSchoolYearForCourseContainer)

    provideAdapter(adapters.getCourseInfoRoot)
    provideAdapter(adapters.getCourseInfoSchoolYear)
    provideAdapter(adapters.getCurrentCourseInfoContainer)
    provideAdapter(adapters.getPublishedCourseInfoContainer)
    provideAdapter(adapters.getCourseInfoRevisionContainer)
    provideAdapter(adapters.getCurrentCourseInfoCourse)
    provideAdapter(adapters.getCurrentCourseInfo)

    # Magical IntIds stub that makes ICourseContainer(SchoolYear)
    # and ISchoolYear(ICourseContainer) adapters work.
    class IntIdsStub(object):
        objects = []

        def getId(self, obj):
            if obj not in self.objects:
                self.objects.append(obj)
                return len(self.objects) - 1
            return self.objects.index(obj)

        def getObject(self, id, default=None):
            return self.objects[id]

    provideUtility(IntIdsStub(), IIntIds)


def tearDown(test=None):
    setup.placefulTearDown()


def test_suite():
    optionflags = (doctest.NORMALIZE_WHITESPACE |
                   doctest.REPORT_ONLY_FIRST_FAILURE |
                   doctest.ELLIPSIS |
                   doctest.REPORT_NDIFF)
    return unittest.TestSuite([
         doctest.DocFileSuite('../README.txt',
         setUp=setUp, tearDown=tearDown,
         optionflags=optionflags),
         ])


if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
